pub struct ProjectConfig {
pub name: String,
pub project_type: ProjectType,
pub target_url: String,
pub environment: Environment,
}Fields
name: Stringproject_type: ProjectTypetarget_url: Stringenvironment: EnvironmentTrait Implementations
Sourceimpl Clone for ProjectConfig
impl Clone for ProjectConfig
Sourceimpl Debug for ProjectConfig
impl Debug for ProjectConfig
Sourceimpl Default for ProjectConfig
impl Default for ProjectConfig
Sourceimpl<'de> Deserialize<'de> for ProjectConfigwhere
ProjectConfig: Default,
impl<'de> Deserialize<'de> for ProjectConfigwhere
ProjectConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProjectConfig
impl JsonSchema for ProjectConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProjectConfig
impl PartialEq for ProjectConfig
Sourceimpl Serialize for ProjectConfig
impl Serialize for ProjectConfig
impl StructuralPartialEq for ProjectConfig