pub struct SpecLoopConfig {
pub schema_version: String,
pub project: ProjectConfig,
pub agent: AgentConfig,
pub browser: BrowserConfig,
pub safety: SafetyConfig,
pub outputs: OutputsConfig,
}Fields
schema_version: Stringproject: ProjectConfigagent: AgentConfigbrowser: BrowserConfigsafety: SafetyConfigoutputs: OutputsConfigTrait Implementations
Sourceimpl Clone for SpecLoopConfig
impl Clone for SpecLoopConfig
Sourcefn clone(&self) -> SpecLoopConfig
fn clone(&self) -> SpecLoopConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpecLoopConfig
impl Debug for SpecLoopConfig
Sourceimpl Default for SpecLoopConfig
impl Default for SpecLoopConfig
Sourceimpl<'de> Deserialize<'de> for SpecLoopConfigwhere
SpecLoopConfig: Default,
impl<'de> Deserialize<'de> for SpecLoopConfigwhere
SpecLoopConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SpecLoopConfig
impl JsonSchema for SpecLoopConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SpecLoopConfig
impl PartialEq for SpecLoopConfig
Sourcefn eq(&self, other: &SpecLoopConfig) -> bool
fn eq(&self, other: &SpecLoopConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SpecLoopConfig
impl Serialize for SpecLoopConfig
impl StructuralPartialEq for SpecLoopConfig